document.addEventListener('DOMContentLoaded', () => {
  const parseMetadataBtn = document.getElementById('parse-metadata');
  const copyQueryBtn = document.getElementById('copy-query');
  let parsedMetadata = null;

  parseMetadataBtn.addEventListener('click', async () => {
    const metadata = document.getElementById('metadata').value;
    if (!metadata.trim()) {
      alert('Please enter database metadata');
      return;
    }

    try {
      parsedMetadata = JSON.parse(metadata);
      showTableSelection(parsedMetadata);
      document.getElementById('table-selection').classList.remove('hidden');
      document.getElementById('transformations').classList.remove('hidden');
      document.getElementById('custom-input').classList.remove('hidden');
      document.getElementById('result').classList.remove('hidden');
    } catch (e) {
      alert('Invalid metadata format. Please ensure it\'s valid JSON.');
    }
  });

  function showTableSelection(metadata) {
    const container = document.getElementById('tables-container');
    container.innerHTML = '';

    Object.entries(metadata).forEach(([tableName, columns]) => {
      const tableDiv = document.createElement('div');
      tableDiv.className = 'table-select';
      
      const tableCheckbox = document.createElement('input');
      tableCheckbox.type = 'checkbox';
      tableCheckbox.id = `table-${tableName}`;
      
      const tableLabel = document.createElement('label');
      tableLabel.htmlFor = `table-${tableName}`;
      tableLabel.textContent = tableName;

      const columnsList = document.createElement('div');
      columnsList.className = 'columns-list';

      columns.forEach(column => {
        const columnCheckbox = document.createElement('input');
        columnCheckbox.type = 'checkbox';
        columnCheckbox.id = `${tableName}-${column}`;
        
        const columnLabel = document.createElement('label');
        columnLabel.htmlFor = `${tableName}-${column}`;
        columnLabel.textContent = column;

        columnsList.appendChild(columnCheckbox);
        columnsList.appendChild(columnLabel);
      });

      tableDiv.appendChild(tableCheckbox);
      tableDiv.appendChild(tableLabel);
      tableDiv.appendChild(columnsList);
      container.appendChild(tableDiv);
    });
  }

  document.querySelectorAll('[data-transform]').forEach(btn => {
    btn.addEventListener('click', () => {
      const transformType = btn.dataset.transform;
      const config = document.getElementById('transformation-config');
      config.innerHTML = getTransformationConfig(transformType);
    });
  });

  function getTransformationConfig(type) {
    const configs = {
      sort: `<div class="transform-config">
              <select id="sort-column">
                <option value="">Select Column</option>
              </select>
              <select id="sort-direction">
                <option value="asc">Ascending</option>
                <option value="desc">Descending</option>
              </select>
            </div>`,
      filter: `<div class="transform-config">
                <select id="filter-column">
                  <option value="">Select Column</option>
                </select>
                <select id="filter-operator">
                  <option value="=">=</option>
                  <option value=">">></option>
                  <option value="<"><</option>
                  <option value="LIKE">LIKE</option>
                </select>
                <input type="text" id="filter-value" placeholder="Value">
              </div>`,
      // Add more transformation configs as needed
    };
    return configs[type] || '';
  }

  copyQueryBtn.addEventListener('click', () => {
    const sqlOutput = document.getElementById('sql-output');
    navigator.clipboard.writeText(sqlOutput.textContent)
      .then(() => {
        copyQueryBtn.textContent = 'Copied!';
        setTimeout(() => {
          copyQueryBtn.textContent = 'Copy Query';
        }, 2000);
      });
  });
});
